<template>
  <gree-popup class="air-popup" position="bottom" get-container="body" v-model="isShow" safe-area-inset-bottom @hide="onHide">
    <gree-radio-list :value="WdSpd" :options="radioLists" @change="onClick"> </gree-radio-list>
  </gree-popup>
</template>

<script>
import { popup, RadioList } from 'gree-ui';
import { types } from '@/store/types';
import { mapState, mapMutations, mapGetters, mapActions } from 'vuex';

export default {
  name: 'AirPopup',
  components: {
    [popup.name]: popup,
    [RadioList.name]: RadioList
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      Air: state => state.dataObject.Air,
      WdSpd: state => state.dataObject.WdSpd,
      AirPopup: state => state.popup.AirPopup,
      StHt: state => state.dataObject.StHt || 0
    }),
    ...mapGetters([
      'modTextKey',
      'modIdentifier',
      'modCurrentStatusName',
      'temSetVal',
      'temSetJson',
      'temMinVal',
      'temMaxVal',
      'spModCurrentStatusName',
      'spModIdentifier'
    ]),
    ...mapGetters('machine', ['statusMap']),
    radioLists() {
      return [
        {
          value: 1,
          text: '低风档'
        },
        {
          value: 3,
          text: '中风档',
          brief: ''
        },
        {
          value: 5,
          text: '高风档',
          brief: ''
        }
      ];
    }
  },
  watch: {
    AirPopup(val) {
      this.isShow = val;
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL,
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE'
    }),
    onClick(option) {
      this.sendData({
        WdSpd: option.value,
        StHt: 0
      });
    },
    onHide() {
      this.SetPopup({ AirPopup: false });
    }
  }
};
</script>

<style lang="scss">
.air-popup {
  width: 100%;
  color: #404657;
  .gree-radio-list {
    .gree-radio-icon {
      .gree-icon.icon-font.checked {
        color: #71acf1;
      }
    }
  }
}
</style>
